pub fn multibin_shared() -> Option<Attribute>Expand description
If multibin feature is enabled, this returns a tokenstream for the attribute #[multibin_shared] to make sure the annotated variable
is present at the same address on all cores. Otherwise None is returned